Description Usage Arguments Details Value Author(s) References Examples
Simulate right censored survival data with two covariates X1 and X2, both have effect exp(1) on the hazard of the unobserved event time.
1 |
N |
sample size |
... |
do nothing |
This function calls survModel, then adds covariates and finally calls sim.lvm.
data.frame with simulated data
Thomas Alexander Gerds
Bender, Augustin & Blettner. Generating survival times to simulate Cox proportional hazards models. Statistics in Medicine, 24: 1713-1723, 2005.
1 | SimSurv(10)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.