neighborhood(x, bandwidth = NULL, kernel = "box")N^{-1/4} is used, N being the sample size, or NULL
in which case the dpik function of the package KernSmooth is
used to find the optimal bandwidth.values) for which a neighborhood,
consisting of the nearest neighbors, is defined by the first neighbor
(first.nbh) of the usually very long vector neighbors and the
size of the neighborhood (size.nbh).Further values are the arguments bandwidth, kernel, the total
sample size n and the number of unique values nu.
dpik, prodlim
d <- SimSurv(20)
neighborhood(d$X2)
Run the code above in your browser using DataLab